@@ -6,24 +6,40 @@ import javax.swing.filechooser.FileFilter;
 
 /**
  * A FileFilter similar to FileNameExtensionFilter except that
- * it allows multipart extensions (.ork.gz).
+ * it allows multipart extensions (.ork.gz), and also implements
+ * the java.io.FileFilter interface.
  * 
  * @author Sampo Niskanen <sampo.niskanen@iki.fi>
  */
-public class SimpleFileFilter extends FileFilter {
+public class SimpleFileFilter extends FileFilter implements java.io.FileFilter {
 
 	private final String description;
+	private final boolean acceptDir;
 	private final String[] extensions;
 	
 	
 	/**
-	 * Sole constructor.
+	 * Create filter that accepts files with the provided extensions that
+	 * accepts directories as well.
 	 * 
 	 * @param description	the description of this file filter.
 	 * @param extensions	an array of extensions that match this filter.
 	 */
 	public SimpleFileFilter(String description, String ... extensions) {
+		this(description, true, extensions);
+	}
+	
+
+	/**
+	 * Create filter that accepts files with the provided extensions.
+	 * 
+	 * @param description	the description of this file filter.
+	 * @param acceptDir		whether to accept directories
+	 * @param extensions	an array of extensions that match this filter.
+	 */
+	public SimpleFileFilter(String description, boolean acceptDir, String ... extensions) {
 		this.description = description;
+		this.acceptDir = acceptDir;
 		this.extensions = new String[extensions.length];
 		for (int i=0; i<extensions.length; i++) {
 			String ext = extensions[i].toLowerCase();
@@ -36,13 +52,12 @@ public class SimpleFileFilter extends FileFilter {
 	}
 	
 	
-	
 	@Override
 	public boolean accept(File file) {
 		if (file == null)
 			return false;
 		if (file.isDirectory())
-			return true;
+			return acceptDir;
 		
 		String filename = file.getName();
 		filename = filename.toLowerCase();
